@@ -3,9 +3,9 @@ package Number::ZipCode::JP::Table::Company;
 use strict;
 use warnings;
 
-our $VERSION = '0.20240531';
+our $VERSION = '0.20240628';
 
-# Table last modified: 2024-05-31
+# Table last modified: 2024-06-28
 our %ZIP_TABLE = (
     '001' => '(?:8(?:5(?:[0-2]1|55|77|88)|612))',
     '002' => '(?:850[1-4])',
@@ -110,8 +110,8 @@ our %ZIP_TABLE = (
     '104' => '(?:(?:8(?:1(?:2[2-589]|5[018]|6[12578]|4[25]|8[389]|7[014-689]|3[0-589]|1[0-24-8]|0[124589])|3(?:1[023579]|7[07-9]|2[458]|8[013689]|6[35]|5[0167]|3[02358]|4[0-5]|0[12467])|4(?:5[06]|3[013589]|1[369]|0[24578]|8[168]|2[0-469]|6[078]|4[02-49])|5(?:3[03]|2[136-8]|4[357]|5[014-689]|6[068]|1[078]|8[1458]|0[1256])|2(?:38|40|71|6[26]|5[124578]|0[568]|8[0-59]|1[0-28])|6(?:14|78|5[06]|8[05]|6[15])|0(?:55|77|1[01]|0[1-37]))|6241))',
     '105' => '(?:(?:8(?:4(?:7[0-257]|8[2-6]|5[1-36-8]|3[13-7]|[46][014-9]|2[0347-9]|1[0-24-9]|0[1-378])|5(?:6[03578]|1[0-2568]|0[1-357-9]|5[013-8]|8[0-57-9]|7[4-9]|2[1-57-9]|3[0457]|4[03-6])|6(?:7[026-8]|3[04]|8[01569]|6[0568]|1[013-5]|2[0135-7]|5[468]|4[0-24]|0[3468])|3(?:1\d|3[01358]|0[1-9]|2[235])|0(?:10|39|55|0[1258]|7[07]|8[58])|7(?:88|0[127]|1[267]))|7(?:0(?:[58]0|77)|36[5-7]|444)|6[09]50))',
     '106' => '(?:(?:8(?:5(?:6[0-35-79]|0[78]|3[17]|1[458]|7[135-8]|2[12]|5[0-25689]|4[145]|8[0157-9])|6(?:77|4[0-2489]|5[25]|1[16]|6[58]|3[0569]|0[18]|2[0256])|0(?:11|39|0[17])|(?:10|79)7|4(?:01|87))|6(?:1(?:61|88)|06[06])))',
-    '107' => '(?:8(?:4(?:20|5[06]|7[127]|0[1-4]|3[14]|1[0-26-9]|8[24]|4[08]|6[038])|5(?:[37]2|81|0[23578]|1[14]|2[0178]|6[037]|5[0268]|4[56])|6(?:01|50|66|1[5-79]|7[46]|3[0-3689]|8[068]|2[0357])|3(?:60|4[0289]|7[013]|2[0346]|8[048]|3[026]|5[125])|0(?:[16]0|77|0[16])))',
-    '108' => '(?:(?:8(?:5(?:2[0-35]|4[0358]|3[02369]|0[1-9]|6[0468]|1[0-25]|7[0135]|5[0-35-8]|8[0-3568])|3(?:2[25689]|3[134]|1[0356]|7[2359]|8[013-689]|5[058]|6[01]|4[15]|0[13578])|2(?:8[028]|2[0-245]|7[056]|4[0-38]|1[0-25-7]|0[1-36-9]|3[0-4]|5[05])|4(?:56|0[3-57]|2[013-5]|7[078]|1[014-7]|3[29]|6[68]|4[48])|6(?:50|1[0-25-7]|2[28]|3[1-3689]|0[267]|4[0-28])|0(?:[258]0|[17]1|0[15])|7(?:07|1[03])|11[78])|63(?:50|63)))',
+    '107' => '(?:8(?:4(?:20|5[06]|7[127]|0[1-4]|3[14]|1[0-26-9]|8[24]|4[08]|6[038])|5(?:32|81|0[23578]|7[02]|1[146]|2[0178]|6[037]|5[0268]|4[56])|6(?:01|50|66|1[5-79]|7[46]|3[0-3689]|8[068]|2[0357])|3(?:60|4[0289]|7[013]|2[0346]|8[048]|3[026]|5[125])|0(?:[16]0|77|0[16])))',
+    '108' => '(?:(?:8(?:5(?:2[0-35]|4[0358]|3[02369]|0[1-9]|6[0468]|1[0-25]|7[0135]|5[0-35-8]|8[0-3568])|3(?:2[25689]|3[134]|1[0356]|7[2359]|8[013-689]|5[058]|6[01]|4[15]|0[13578])|2(?:8[028]|7[056]|4[0-38]|1[0-25-7]|0[1-36-9]|3[0-4]|5[05]|2[0245])|4(?:56|0[3-57]|2[013-5]|7[078]|1[014-7]|3[29]|6[68]|4[48])|6(?:50|1[0-25-7]|2[28]|3[1-3689]|0[267]|4[0-28])|0(?:[258]0|[17]1|0[15])|7(?:07|1[03])|11[78])|63(?:50|63)))',
     '109' => '(?:8792)',
     '110' => '(?:8(?:5(?:6[0-25-7]|4[01368]|7[5-8]|3[0-4679]|0[1-3579]|1[0135-7]|5[059]|8[02-468]|2[024])|6(?:53|2[0-2568]|6[0259]|3[0158]|4[124-6]|0[259]|8[015-7]|1[04589]|7[35-8])|7(?:8[027]|1[2-6]|2[235]|3[36]|0[68])|408|807))',
     '111' => '(?:8(?:6(?:3[01379]|[12][0-258]|7[6-8]|8[1368]|0[2568]|6[16]|5[05]|4[0248])|5(?:43|1[0-258]|8[058]|5[1568]|7[57]|6[0167]|2[125]|0[125-8]|3[0-59])|7(?:[56]5|21|98|0[178]|1[01])|081))',
@@ -125,12 +125,12 @@ our %ZIP_TABLE = (
     '123' => '(?:85(?:[58]8|40|1[1247]|0[135-9]))',
     '124' => '(?:85(?:60|77|2[04]|3[03589]|0[1-39]|8[58]|5[05]|1[01]))',
     '125' => '(?:8(?:5(?:0[3-8]|8[58]|1[1-47]|2[026])|601))',
-    '130' => '(?:8(?:5(?:8[03-58]|2[0-258]|7[057]|3[013-589]|5[3-8]|4[3568]|6[135-7]|0[13-9]|1[0-8])|6(?:25|71|86|4[02]|3[367]|5[05]|6[068]|1[125]|0[1-689])|7(?:[12]0|0[16])))',
+    '130' => '(?:8(?:5(?:8[03-58]|2[0-258]|7[057]|3[013-589]|5[3-8]|4[3568]|6[135-7]|0[13-9]|1[0-8])|6(?:71|86|4[02]|3[367]|5[05]|2[58]|6[068]|1[125]|0[1-689])|7(?:[12]0|0[16])))',
     '131' => '(?:8(?:5(?:65|1[0-389]|3[03]|2[0467]|5[058]|8[458]|0[1357-9])|139|634|711))',
     '132' => '(?:8(?:5(?:[18]5|33|5[015]|0[137]|6[27])|6(?:01|74|[68][68])|7(?:11|3[029])))',
     '133' => '(?:8(?:5(?:[01]1|8[05]|5[238])|70[46]))',
     '134' => '(?:8(?:5(?:[15]5|20|33|7[05-7]|8[5-8]|0[237])|6(?:22|86|[14][02]|0[1-39]|3[01])|702))',
-    '135' => '(?:8(?:5(?:48|3[0-358]|7[57-9]|2[1-3578]|8[1257]|1[0-478]|5[0-24-9]|0[12458]|6[035-8])|4(?:4[0358]|2[27]|0[24]|5[18]|8[0-2]|7[037]|6[014]|1[15]|3[026])|6(?:86|0[28]|2[0-25]|6[168]|3[0-29]|7[078]|1[014-9]|5[059])|3(?:[25]0|8[3-57]|0[1368]|7[05]|6[023]|3[01]|1[0-28])|1(?:[46]5|21|50|78|1[01458]|0[89]|3[0479]|8[01])|7(?:97|3[0-3]|2[0-37]|0[17]|1[0178])|2(?:10|2[24])|0(?:74|80)))',
+    '135' => '(?:8(?:5(?:48|3[0-358]|7[57-9]|2[1-3578]|8[1257]|1[0-478]|5[0-24-9]|0[12458]|6[035-8])|4(?:4[0358]|2[27]|0[24]|5[18]|8[0-2]|7[037]|6[014]|1[15]|3[026])|6(?:86|0[28]|2[0-25]|6[168]|3[0-29]|7[078]|1[014-9]|5[059])|3(?:[25]0|8[3-57]|0[1368]|7[05]|6[023]|3[01]|1[0-28])|1(?:21|50|65|78|1[01458]|0[89]|3[0479]|8[01])|7(?:97|3[0-3]|2[0-37]|0[17]|1[0178])|2(?:10|2[24])|0(?:74|80)))',
     '136' => '(?:8(?:5(?:3[135]|4[03]|5[056]|8[01589]|1[2357]|7[057]|6[07]|0[1257]|2[1-35])|6(?:51|8[06]|1[25]|[37][0157]|2[0267]|6[68]|4[08]|0[3578])|7(?:[23]3|11)|88[018]|405|908))',
     '137' => '(?:8(?:6(?:23|86)|08[18]|581))',
     '140' => '(?:8(?:5(?:90|4[0137-9]|3[0136-9]|7[1-46]|0[23679]|8[0346]|6[0367]|2[1-3569]|5[1248]|1[1256])|6(?:4[04]|3[0147]|2[1568]|6[013689]|7[025-8]|5[03-68]|0[12]|8[0278]|1[14-79])|7(?:88|1[015-7]|2[12]|0[279])|(?:45|81)0))',
@@ -139,7 +139,7 @@ our %ZIP_TABLE = (
     '143' => '(?:85(?:70|5[02578]|3[013589]|2[0158]|8[05]|6[0578]|1[13-5]|0[2457-9]|4[014]))',
     '144' => '(?:8(?:5(?:44|66|5[015]|8[018]|7[057]|2[25]|3[1-356]|1[01356]|0[56])|6(?:02|11|5[056]|7[78]|2[1-36]|6[016])))',
     '145' => '(?:85(?:[23]3|58|66|0[16]|1[15]))',
-    '146' => '(?:8(?:5(?:22|31|67|0[135]|5[158]|8[058]|1[0-25]|7[67]|4[034])|6(?:[03]1|10|77|2[03]|5[056]|6[68])))',
+    '146' => '(?:8(?:5(?:22|31|55|67|1[025]|0[13]|8[058]|7[67]|4[034])|6(?:[03]1|[15]0|77|2[03]|6[68])))',
     '150' => '(?:8(?:5(?:45|6[37]|2[256]|0[1-357-9]|7[57]|8[578]|1[0-24-7]|5[1-5]|3[038])|3(?:19|84|4[03]|7[37]|3[0368]|0[17]|2[24-8]|5[05]|6[036])|4(?:12|36|55|0[289]|8[28]|4[08])|9(?:02|11|40|55|67|2[35]|3[258])|0(?:[08]1|1[059])|6(?:88|7[237])))',
     '151' => '(?:8(?:5(?:[34]\d|0[2-79]|5[024589]|1[016-9]|6[1-35-9]|2[0-57-9]|9[0-2]|7[0-46-8]|8[02-7])|6(?:5[1-3]|7[1-7]|0[01])|40[14]|070))',
     '152' => '(?:8(?:5(?:61|4[149]|2[0-257]|0[36-8]|7[08]|1[01]|5[0-28]|3[1-35])|9(?:1[03]|0[24579])|6[02]1))',
@@ -192,7 +192,7 @@ our %ZIP_TABLE = (
     '203' => '(?:8(?:5(?:[12]1|55|8[58])|601|739))',
     '204' => '(?:85(?:[01]1|22|33|67|5[58]|8[589]))',
     '205' => '(?:8(?:5(?:11|55|0[13])|6(?:60|0[1467])))',
-    '206' => '(?:8(?:5(?:30|77|4[03]|2[025]|8[568]|1[0-25]|6[167]|0[235]|5[15])|6(?:[01]1|[68]6)))',
+    '206' => '(?:8(?:5(?:30|77|4[03]|2[025]|0[25]|8[568]|1[0-25]|6[167]|5[15])|6(?:[01]1|[68]6)))',
     '207' => '(?:85(?:[18]5|01))',
     '208' => '(?:85(?:[58]5|0[1-3]))',
     '210' => '(?:(?:8(?:5(?:0[246]|6[0259]|2[13]|8[356]|3[178]|4[013-578]|7[067]|1[12]|5[127-9])|6(?:66|0[24]|8[016])|79[3-8])|9(?:5(?:11|26|55|67|82|3[03]|0[17])|650)))',
@@ -222,7 +222,7 @@ our %ZIP_TABLE = (
     '240' => '(?:(?:8(?:5(?:[02]1|[45]0)|612)|019[235-8]))',
     '241' => '(?:8(?:5(?:25|1[25]|0[12])|606))',
     '242' => '(?:8(?:5(?:[58]5|77|0[27])|6(?:01|10)))',
-    '243' => '(?:(?:8(?:5(?:88|5[015]|3[13]|7[17]|2[12]|1[01]|0[15])|6(?:89|0[14]))|0(?:4(?:60|8[02-79]|9[2367])|2(?:81|9[278])|19[23578]|392)))',
+    '243' => '(?:(?:8(?:5(?:88|5[015]|3[13]|7[17]|2[12]|1[01]|0[15])|6(?:89|0[14]))|0(?:4(?:60|9[2-467]|8[02-79])|2(?:81|9[278])|19[23578]|392)))',
     '244' => '(?:8(?:5(?:0[1-3]|7[17]|2[28]|5[058]|8[589]|6[679]|1[01]|3[039])|60[12]))',
     '245' => '(?:8(?:5(?:[16]0|42|89|5[058]|7[57])|65[01]))',
     '246' => '(?:85(?:20|5[06]))',
@@ -238,7 +238,7 @@ our %ZIP_TABLE = (
     '256' => '(?:8510)',
     '257' => '(?:85(?:[23]3|11|55|66|77|8[458]|0[12]))',
     '258' => '(?:(?:85(?:11|77|85|3[38]|0[16])|0195))',
-    '259' => '(?:(?:0(?:1(?:9[2-467]|8[01])|39[2356])|1(?:1(?:8[5-8]|9[236-8])|[23]92)))',
+    '259' => '(?:(?:0(?:1(?:9[2-467]|8[01])|39[2356])|1(?:1(?:8[5-8]|9[236-8])|292)))',
     '260' => '(?:8(?:6(?:0[13467]|1[0-389]|2[0-24-79]|5[46]|4[2578]|6[0-35-8]|7[0-357]|8[258]|3[135-7])|5(?:40|7[0257]|5[1257-9]|8[0568]|1[0-35-8]|0[1-35-9]|3[4-68]|6[0-467]|2[13478])|7(?:1[02357]|0[137]|3[34]|2[02])))',
     '261' => '(?:8(?:5(?:1[0-35]|6[0168]|3[0359]|7[57]|5[0248]|0[1-478]|8[125-8]|4[145]|2[0-28])|6(?:09|86)|733))',
     '262' => '(?:8(?:5(?:0[26]|1[0-24])|733))',
@@ -253,7 +253,7 @@ our %ZIP_TABLE = (
     '274' => '(?:8(?:5(?:[12]0|77|85|3[03]|0[13-7]|5[58])|601))',
     '275' => '(?:8(?:5(?:02|11|33|[28][058]|6[05]|7[25-7]|5[01])|6(?:[01]1|66)))',
     '276' => '(?:85(?:01|80|2[3-7]))',
-    '277' => '(?:8(?:5(?:1[1589]|0[13-57]|8[124-9]|5[0146-8]|3[139]|2[0-2]|7[0-479]|6[1-69])|6(?:86|5[45]|6[16])))',
+    '277' => '(?:8(?:5(?:2[0-25]|1[1589]|0[13-57]|8[124-9]|5[0146-8]|3[139]|7[0-479]|6[1-69])|6(?:86|5[45]|6[16])))',
     '278' => '(?:8(?:5(?:[02]1|10|33|7[07]|5[05])|6(?:01|86)))',
     '279' => '(?:8(?:5(?:41|67|70|0[1-6]|5[0358]|8[0-358]|2[1-35-79]|1[1269]|3[0-2])|6(?:01|86)))',
     '282' => '(?:86(?:02|10))',
@@ -425,7 +425,7 @@ our %ZIP_TABLE = (
     '451' => '(?:8(?:5(?:[14]1|2[02]|[56][0158]|0[1-38]|7[0157])|6(?:[15]0|66|88)|701))',
     '452' => '(?:8(?:5(?:70|0[1-3]|6[1-79])|60[12]))',
     '453' => '(?:8(?:5(?:40|8[015]|3[39]|7[07]|5[58]|6[57]|2[12]|0[15]|1[0-28])|6(?:[28]6|11|62|0[18])|7(?:58|65|77|0[14])))',
-    '454' => '(?:8(?:5(?:3[03]|2[0-24-79]|5[058]|1[124-9]|6[05]|0[1-689])|651))',
+    '454' => '(?:8(?:5(?:3[03]|2[0-24-79]|5[058]|1[125-9]|6[05]|0[1-689])|651))',
     '455' => '(?:8(?:5(?:[458]5|60|1[25]|[02][15]|3[035])|6(?:[46]8|10|2[06]|3[09]|0[156]|7[01])|777))',
     '456' => '(?:8(?:5(?:23|30|44|0[1-3]|6[07]|1[16]|8[0578]|5[56])|6(?:20|91|0[12]|1[0-2]|[68][68])|7(?:11|39|63)))',
     '457' => '(?:8(?:5(?:22|45|77|3[0-35]|5[158]|1[0-25]|6[067]|8[58]|0[18])|71[12]))',
@@ -509,7 +509,7 @@ our %ZIP_TABLE = (
     '537' => '(?:8(?:(?:50|91)1|686))',
     '538' => '(?:8(?:5(?:[58]5|01|10)|6(?:[68]6|55)))',
     '539' => '(?:8794)',
-    '540' => '(?:(?:8(?:5(?:6[06]|5[0-3589]|4[0147]|2[0-267]|8[15-7]|3[03-5]|0[1578]|7[01578]|1[0-2579])|6(?:86|1[015]|4[25]|2[02]|3[09]|0[2-8]|7[078]|6[08])|795)|6255))',
+    '540' => '(?:(?:8(?:5(?:6[06]|4[0147]|5[0-357-9]|2[0-267]|8[15-7]|3[03-5]|0[1578]|7[01578]|1[0-2579])|6(?:86|1[015]|4[25]|2[02]|3[09]|0[2-8]|7[078]|6[08])|795)|6255))',
     '541' => '(?:(?:8(?:5(?:5[0136-9]|2[013-689]|7[2568]|1[135-9]|4[0-357]|8[1579]|0[1-35689]|6[0136-8]|3[014578])|630|765)|6666))',
     '542' => '(?:8(?:5(?:33|42|77|0[1-4]|8[0568]|6[67]|2[235]|5[0458]|1[01])|6(?:54|60|8[68])|745))',
     '543' => '(?:8(?:5(?:[34]3|11|0[1-3]|[58][58])|6(?:01|66|8[68])))',
@@ -518,7 +518,7 @@ our %ZIP_TABLE = (
     '546' => '(?:8501)',
     '547' => '(?:85(?:01|80|1[04]))',
     '549' => '(?:85(?:11|22|85))',
-    '550' => '(?:8(?:5(?:10|27|41|5[025]|8[057]|6[67]|7[0578]|3[08]|0[1-358])|6(?:59|60)))',
+    '550' => '(?:8(?:5(?:10|27|41|8[05-7]|5[025]|6[67]|7[0578]|3[08]|0[1-358])|6(?:59|60)))',
     '551' => '(?:85[015]1)',
     '552' => '(?:85(?:01|10))',
     '553' => '(?:8(?:5(?:67|1[1-3]|0[13]|5[0358]|8[58])|739))',
@@ -540,11 +540,11 @@ our %ZIP_TABLE = (
     '570' => '(?:8(?:5(?:39|40|0[167]|[58][58]|1[15])|6(?:34|66)|787))',
     '571' => '(?:8(?:5(?:[45]5|33|67|71|8[05]|0[2-47])|6(?:[24]0|33|86)))',
     '572' => '(?:85(?:40|8[01589]|0[158]|2[28]|3[013]|7[02]|5[0158]|6[67]|1[01]))',
-    '573' => '(?:(?:8(?:5(?:34|56|67|73|88|0[58]|1[01])|666)|10(?:[34]0|1[03]|0[1478])|019[356]))',
+    '573' => '(?:(?:8(?:5(?:34|56|67|73|88|0[58]|1[01])|6(?:54|66))|10(?:[34]0|1[03]|0[1478])|019[356]))',
     '574' => '(?:85(?:[58]5|01|3[0-4]))',
     '575' => '(?:85(?:[01]1|30|[58][58]))',
     '576' => '(?:8501)',
-    '577' => '(?:85(?:40|3[37]|0[2359]|5[01458]|8[1258]|6[067]|7[57]|2[0-2]|1[01]))',
+    '577' => '(?:8(?:5(?:40|3[37]|0[2359]|5[01458]|8[1258]|6[067]|7[57]|2[0-2]|1[01])|666))',
     '578' => '(?:85(?:22|55|77|3[35]|8[58]|0[12]|1[15]))',
     '579' => '(?:8502)',
     '580' => '(?:8(?:50[1-5]|601))',
@@ -594,7 +594,7 @@ our %ZIP_TABLE = (
     '627' => '(?:8(?:5(?:55|67|70)|688))',
     '629' => '(?:(?:0(?:19[26-8]|39[28])|2(?:292|498)|1192))',
     '630' => '(?:(?:8(?:5(?:3[0356]|2[0289]|1[28]|6[367]|7[0578]|0[1-3568]|4[038]|5[0258]|8[0157-9])|6(?:7[07]|[68][68]|5[15]))|0(?:2(?:88|9[23])|192)|2192))',
-    '631' => '(?:85(?:[58]5|11|2[2-4]|0[1-35]))',
+    '631' => '(?:85(?:11|55|2[2-4]|8[56]|0[1-35]))',
     '632' => '(?:(?:8(?:5(?:[14]0|[67]7|8[578]|5[258])|6(?:79|88))|0292))',
     '633' => '(?:(?:8(?:5(?:[58]5|01|38)|686)|0(?:29[28]|39[28])|2[14]92))',
     '634' => '(?:85(?:5[015]|2[1-4]|8[056]|0[1-35-7]|1[01]|6[017]))',
@@ -638,7 +638,7 @@ our %ZIP_TABLE = (
     '672' => '(?:8(?:5(?:01|67|5[058]|8[58])|6(?:55|66|77)))',
     '673' => '(?:(?:8(?:5(?:[01]1|[58]5|22)|6(?:66|8[68]))|1(?:49[2-5]|192|395)|0[45]92))',
     '674' => '(?:8(?:5(?:01|85)|686))',
-    '675' => '(?:(?:8(?:5(?:22|33|77|88|1[019]|6[67]|5[58]|0[15])|6(?:11|8[68]))|01(?:8[0-68]|9[2-68])|1(?:3(?:80|9[25])|192|297)|239[35]))',
+    '675' => '(?:(?:8(?:5(?:22|33|77|88|1[019]|6[67]|5[58]|0[15])|6(?:11|75|8[68]))|01(?:8[0-68]|9[2-68])|1(?:3(?:80|9[25])|192|297)|239[35]))',
     '676' => '(?:8(?:5(?:01|33|40|58|66|85|1[03])|6(?:55|7[07]|8[68])))',
     '677' => '(?:851[01])',
     '678' => '(?:(?:1(?:29[257]|19[58])|0(?:19[235]|292)|85(?:43|85)))',
@@ -690,7 +690,7 @@ our %ZIP_TABLE = (
     '728' => '(?:85(?:11|0[1-3]))',
     '729' => '(?:(?:3(?:19[238]|49[278]|592)|0(?:49[25]|292|393)|2(?:39[2-4]|292)|149[23]|4295|5792))',
     '730' => '(?:8(?:5(?:4[0-58]|6[1-35-7]|8[0235-79]|1[013-58]|5[0-289]|0[1-47-9]|7[015-7]|3[0-35689]|2[0-378])|6(?:7[02578]|4[1-36]|1[0-29]|8[067]|6[126-8]|5[0-8]|3[01]|2[026]|0[135689])|7(?:[23]0|87|0[1267]|9[4-7])))',
-    '731' => '(?:(?:0(?:19[2-8]|29[235]|59[235]|692)|3(?:19[2-68]|39[358]|595)|4(?:39[236-8]|29[2-4])|1(?:59[57]|795)|519[35-8]|219[58]))',
+    '731' => '(?:(?:0(?:19[2-8]|29[235]|59[235]|692)|3(?:19[2-68]|39[358]|595)|4(?:39[236-8]|29[23])|1(?:59[57]|795)|519[35-8]|219[58]))',
     '732' => '(?:8(?:5(?:55|80|6[4-6]|7[05]|1[0-2]|0[13-57-9])|652|765))',
     '733' => '(?:8(?:6(?:89|3[03]|4[1-36-8]|6[09]|7[0578]|0[18]|2[1-7]|5[01]|1[016])|5(?:0[19]|4[0358]|5[0-358]|2[0158]|3[0135]|1[0-4])|701))',
     '734' => '(?:8(?:5(?:[37]0|22|43|58|6[07]|1[035])|798))',
@@ -937,7 +937,7 @@ our %ZIP_TABLE = (
     '980' => '(?:(?:8(?:4(?:7[78]|4[1-35-8]|8[014-8]|0[1-36-8]|2[0-369]|1[0145]|3[013569]|5[02-468]|6[016])|5(?:[15][015]|3[134]|7\d|4[346]|0[158]|2[1569]|6[0156]|8[013578])|6(?:40|86|5[0-26]|6[018]|0[1258]|7[17]|3[1-36-9]|2[12])|7(?:11|33|77|0[137]|9[2-578]))|6(?:0(?:55|88)|1(?:61|80))))',
     '981' => '(?:(?:3(?:2(?:8[0178]|9[235-8])|6(?:8[0-24-68]|9[278])|1(?:9[2-5]|8[0589])|49[4-7]|[35]92)|85(?:10|33|85|2[23]|6[03]|5[0-26-8]|0[25]|7[07]|4[035])|1(?:5(?:8[1-3]|9[2356])|29[2-58])|4(?:29[2-4]|392)|0394|2192))',
     '982' => '(?:8(?:5(?:31|44|66|77|2[13]|8[58]|5[15]|1[01]|0[125])|601|798))',
-    '983' => '(?:8(?:5(?:43|70|85|6[0257]|0[1247]|3[367]|2[023]|1[1-37]|5[1256])|6(?:01|22|39)|477))',
+    '983' => '(?:8(?:5(?:43|85|6[0257]|0[1247]|3[367]|2[023]|1[1-37]|5[1256])|6(?:01|22)|477))',
     '984' => '(?:8(?:5(?:0[135]|7[057]|2[25]|6[0178]|8[0458]|3[0389]|1[0-2689]|5[0-3578]|4[035])|6(?:42|54|7[056]|0[13]|8[068]|6[689])))',
     '985' => '(?:8(?:5(?:77|5[015]|2[12]|1[01]|0[12467]|3[13578])|6(?:55|0[17])))',
     '986' => '(?:(?:85(?:40|55|0[17]|2[25]|8[05])|0(?:195|792)|229[23]))',
